GN_DL_URL = "http://download.geonames.org/export/dump/"

GN_PL_HEADERS = [
    "geonameid",
    "name",
    "asciiname",
    "alternatenames",
    "latitude",
    "longitude",
    "feature class",
    "feature code",
    "country code",
    "cc2",
    "admin1 code",
    "admin2 code",
    "admin3 code",
    "admin4 code",
    "population",
    "elevation",
    "dem",
    "timezone",
    "modification date"
]

FEATURE_CODE_LANG = [
    "bg",
    "en",
    "nb",
    "nn",
    "no",
    "ru",
    "sv",
]

FEATURE_CODE_HEADERS = [
    "code",
    "pref_label",
    "description"
]
